# -*- coding: utf-8 -*-
from __future__ import unicode_literals

#: Name pieces that appear before a last name. They join to the piece that follows them to make one new piece.
PREFIXES = set([
    'abu',
    'bin',
    'bon',
    'da',
    'dal',
    'de',
    'degli',
    'dei',
    'del',
    'dela',
    'della',
    'delle',
    'delli',
    'dello',
    'der',
    'di',
    'du',
    'dí',
    'ibn',
    'la',
    'le',
    'san',
    'santa',
    'st',
    'ste',
    'van',
    'vel',
    'von',
])
